@@ -44,21 +44,6 @@
 #' @param row_names_subset if set to TRUE, row.names are used to subset
 #' env_data_primary, env_data_control and response data frames. Only years from
 #' all three data frames are kept.
-#' @param PCA_transformation if set to TRUE, all variables in the response
-#' data frame will be transformed using PCA transformation.
-#' @param log_preprocess if set to TRUE, variables will be transformed with
-#' logarithmic transformation before used in PCA
-#' @param components_selection character string specifying how to select the Principal
-#' Components used as predictors.
-#' There are three options: "automatic", "manual" and "plot_selection". If
-#' argument is set to automatic, all scores with eigenvalues above 1 will be
-#' selected. This threshold could be changed by changing the
-#' eigenvalues_threshold argument. If parameter is set to "manual", user should
-#' set the number of components with N_components argument. If components
-#' selection is set to "plot_selection", Scree plot will be shown and a user must
-#' manually enter the number of components to be used as predictors.
-#' @param eigenvalues_threshold threshold for automatic selection of Principal Components
-#' @param N_components number of Principal Components used as predictors
 #' @param aggregate_function_env_data_primary character string specifying how the
 #' daily data from env_data_primary should be aggregated. The default is 'mean',
 #' the other options are 'median', 'sum', 'min' and 'max'
@@ -77,10 +62,8 @@
 #' @param k integer, number of breaks (splits) for temporal stability
 #' @param subset_years a subset of years to be analyzed. Should be given in the form of
 #' subset_years = c(1980, 2005)
-#' @param plot_specific_window integer representing window width to be displayed
-#' for plot_specific
-#' @param ylimits limit of the y axes for plot_extreme and plot_specific. It should be
-#' given in the form of: ylimits = c(0,1)
+#' @param ylimits limit of the y axes for plot_extreme It should be given in the
+#' form of: ylimits = c(0,1)
 #' @param seed optional seed argument for reproducible results
 #' @param tidy_env_data_primary if set to TRUE, env_data_primary should be inserted as a
 #' data frame with three columns: "Year", "DOY", "Precipitation/Temperature/etc."
@@ -114,28 +97,33 @@
 #' indicate previous growing season days. This argument overwrites the calculation
 #' limits defined by lower_limit and upper_limit arguments.
 #' @param dc_method a character string to determine the method to detrend climate
-#' (environmental) data.  Possible values are c("Spline", "ModNegExp", "Mean",
-#' "Friedman", "ModHugershoff"). Defaults to "none" (see dplR R package).
-#' @param dc_nyrs a number giving the rigidity of the smoothing spline, defaults
-#' to 0.67 of series length if nyrs is NULL (see dplR R package).
-#' @param dc_f a number between 0 and 1 giving the frequency response or wavelength
-#' cutoff. Defaults to 0.5 (see dplR R package).
-#' @param dc_pos.slope a logical flag. Will allow for a positive slope to be used
-#' in method "ModNegExp" and "ModHugershoff". If FALSE the line will be horizontal
-#' (see dplR R package).
-#' @param dc_constrain.nls a character string which controls the constraints of
-#' the "ModNegExp" model and the "ModHugershoff"  (see dplR R package).
-#' @param dc_span a numeric value controlling method "Friedman", or "cv" (default)
-#' for automatic choice by cross-validation (see dplR R package).
-#' @param dc_bass a numeric value controlling the smoothness of the fitted curve
-#' in method "Friedman" (see dplR R package).
-#' @param dc_difference	a logical flag. Compute residuals by subtraction if TRUE,
-#' otherwise use division (see dplR R package).
+#' data.  Possible values are "none" (default) and "SLD" which refers to Simple
+#' Linear Detrending
 #' @param pcor_na_use an optional character string giving a method for computing
 #' covariances in the presence of missing values for partial correlation
 #' coefficients. This must be (an abbreviation of) one of the strings "all.obs",
 #' "everything", "complete.obs", "na.or.complete", or "pairwise.complete.obs"
 #' (default). See also the documentation for the base partial.r in psych R package
+#' @param skip_window_length an integer specifying the frequency of window
+#' selection for the calculations of climate-growth relationships. The default
+#' value is 1, indicating that every window is included in the calculations.
+#' When set to a value greater than 1, the function selectively processes
+#' windows at regular intervals defined by this parameter. For instance, if
+#' skip_window_length = 2, the function processes every second window.
+#' Similarly, if skip_window_length = 3, every third window is processed,
+#' skipping two windows in between each selected one. This parameter allows for
+#' controlling the granularity of the analysis and can help in reducing
+#' computation time by focusing on a subset of the data.
+#' @param skip_window_position an integer specifying the frequency of window
+#' positions used in the calculations of climate-growth relationships. The
+#' default value is 1, indicating that every window position is included in the
+#' calculations. When set to a value greater than 1, the function selectively
+#' processes window positions at regular intervals defined by this parameter.
+#' For instance, if skip_window_position = 2, the function processes every
+#' second window position. Similarly, if skip_window_position = 3, every third
+#' window position is processed, skipping two positions in between each selected
+#' one. This parameter allows for controlling the granularity of the analysis
+#' and can help in reducing computation time by focusing on a subset of the data.
 #'
 #' @return a list with 15 elements:
 #' \enumerate{
@@ -150,8 +138,6 @@
 #'  \item $cross_validation - not available for partial correlations
 #'  \item $plot_heatmap - ggplot2 object: a heatmap of calculated metrics
 #'  \item $plot_extreme - ggplot2 object: line plot of a row with the highest value in a matrix of calculated metrics
-#'  \item $plot_specific -  ggplot2 object: line plot of a row with a selected window width in a matrix of calculated metrics
-#'  \item $PCA_output - princomp object: the result output of the PCA analysis
 #'  \item $type - the character string describing type of analysis: daily or monthly
 #'  \item $reference_window - character string, which reference window was used for calculations
 #'  \item $aggregated_climate_primary - matrix with all aggregated climate series of primary data
@@ -162,6 +148,13 @@
 #'
 #' @examples
 #' \donttest{
+#'
+#' # The examples below are enclosed within donttest{} to minimize the execution
+#' # time during R package checks. Additionally, all examples include the
+#' # parameters `skip_window_length` and `skip_window_position`, which limit the
+#' # number of combinations evaluated in climate-growth correlation calculations.
+#' # To explore all possible combinations, users should set both parameters to 1.
+#'
 #' # Load the dendroTools R package
 #' library(dendroTools)
 #'
@@ -174,28 +167,33 @@
 #' data(LJ_daily_temperatures)
 #' data(LJ_daily_precipitation)
 #'
-#' # 1 Basic example
+#' # 1 Basic example using the partial correlation coefficient
 #' example_basic <- daily_response_seascorr(response = data_MVA,
 #'                           env_data_primary = LJ_daily_temperatures,
 #'                           env_data_control = LJ_daily_precipitation,
-#'                           row_names_subset = TRUE, fixed_width = 25,
+#'                           row_names_subset = TRUE,
+#'                           fixed_width = 25,
 #'                           lower_limit = 35, upper_limit = 45,
-#'                           remove_insignificant = TRUE,
-#'                           aggregate_function_env_data_primary = 'median',
-#'                           aggregate_function_env_data_control = 'median',
-#'                           alpha = 0.05, pcor_method = "spearman",
+#'                           remove_insignificant = FALSE,
+#'                           aggregate_function_env_data_primary = 'mean',
+#'                           aggregate_function_env_data_control = 'mean',
 #'                           tidy_env_data_primary = FALSE,
+#'                           tidy_env_data_control = TRUE,
+#'                           alpha = 0.05, pcor_method = "spearman",
 #'                           previous_year = FALSE, boot = TRUE,
-#'                           tidy_env_data_control = TRUE, boot_n = 10,
+#'                           boot_n = 10,
 #'                           reference_window = "end", k = 5,
-#'                           day_interval = c(-100, 250))
-#' summary(example_basic)
-#' plot(example_basic, type = 1)
-#' plot(example_basic, type = 2)
-#' plot(example_basic, type = 3)
-#' example_basic$optimized_return
-#' example_basic$optimized_return_all
-#' example_basic$temporal_stability
+#'                           dc_method = "SLD",
+#'                           day_interval = c(-100, 250),
+#'                           skip_window_position = 50,
+#'                           skip_window_length= 50
+#'                           )
+#' # summary(example_basic)
+#' # plot(example_basic, type = 1)
+#' # plot(example_basic, type = 2)
+#' # example_basic$optimized_return
+#' # example_basic$optimized_return_all
+#' # example_basic$temporal_stability
 #'
 #' # 2 Example with fixed temporal time window
 #' example_fixed_width <- daily_response_seascorr(response = data_MVA,
@@ -206,16 +204,19 @@
 #'                           aggregate_function_env_data_primary = 'mean',
 #'                           aggregate_function_env_data_control = 'mean',
 #'                           alpha = 0.05,
+#'                           dc_method = "SLD",
 #'                           fixed_width = 45,
 #'                           tidy_env_data_primary = FALSE,
 #'                           tidy_env_data_control = TRUE,
-#'                           reference_window = "end")
+#'                           reference_window = "end",
+#'                           skip_window_position = 50,
+#'                           skip_window_length= 50)
 #'
-#' summary(example_fixed_width)
-#' plot(example_fixed_width, type = 1)
-#' plot(example_fixed_width, type = 2)
-#' example_fixed_width$optimized_return
-#' example_fixed_width$optimized_return_all
+#' # summary(example_fixed_width)
+#' # plot(example_fixed_width, type = 1)
+#' # plot(example_fixed_width, type = 2)
+#' # example_fixed_width$optimized_return
+#' # example_fixed_width$optimized_return_all
 #'
 #' }
 
@@ -225,15 +226,11 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
                            previous_year = FALSE, pcor_method = "pearson",
                            remove_insignificant = TRUE,
                            alpha = .05, row_names_subset = FALSE,
-                           PCA_transformation = FALSE, log_preprocess = TRUE,
-                           components_selection = 'automatic',
-                           eigenvalues_threshold = 1,
-                           N_components = 2,
                            aggregate_function_env_data_primary = 'mean',
                            aggregate_function_env_data_control = 'mean',
                            temporal_stability_check = "sequential", k = 2,
                            k_running_window = 30,
-                           subset_years = NULL, plot_specific_window = NULL,
+                           subset_years = NULL,
                            ylimits = NULL, seed = NULL, tidy_env_data_primary = FALSE,
                            tidy_env_data_control = FALSE,
                            reference_window = 'start',  boot = FALSE, boot_n = 1000,
@@ -242,14 +239,9 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
                                                    previous_year == TRUE),
                                                  c(-1, 366), c(1, 366)),
                            dc_method = NULL,
-                           dc_nyrs = NULL,
-                           dc_f = 0.5,
-                           dc_pos.slope = FALSE,
-                           dc_constrain.nls = c("never", "when.fail", "always"),
-                           dc_span = "cv",
-                           dc_bass = 0,
-                           dc_difference = FALSE,
-                           pcor_na_use = "pairwise.complete") {
+                           pcor_na_use = "pairwise.complete",
+                           skip_window_length = 1,
+                           skip_window_position = 1){
 
   ##############################################################################
   # 1 day interval is organized
@@ -498,13 +490,13 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
 
   }
 
+  # Make sure the selected method is appropriate
   # Make sure the selected method is appropriate
   if (!is.null(dc_method)){
 
-    if (!(dc_method %in% c("Spline", "ModNegExp", "Mean", "Friedman", "ModHugershoff"))){
+    if (!(dc_method %in% c("SLD"))){
 
-      stop(paste0('dc_method should be one of "Spline", "ModNegExp", "Mean", "Friedman", "ModHugershoff",
-         but instead it is:',dc_method))
+      stop(paste0('dc_method should be SLD but instead it is:',dc_method))
 
     }
   }
@@ -621,48 +613,6 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
   }
 
 
-  # If PCA_transformation = TRUE, PCA is performed
-  if (PCA_transformation == TRUE) {
-
-    # Logarithmic transformation before PCA
-    if (log_preprocess == TRUE) {
-
-      if (sum(response <= 0) > 1){
-        stop("your response data contains negative observations. Please set the argument log_preprocess to FALSE")
-      }
-
-      response <- data.frame(log(response))
-    }
-
-    PCA_result <- princomp(response, cor = TRUE)
-
-    if (components_selection == 'automatic'){
-      subset_vector <- PCA_result$sdev > eigenvalues_threshold
-      response <- as.data.frame(PCA_result$scores[, subset_vector])
-    }
-
-    if (components_selection == 'manual'){
-      response <- as.data.frame(PCA_result$scores[, 1:N_components])
-    }
-
-    if (components_selection == 'plot_selection'){
-      plot(PCA_result, type = 'l')
-
-      fun <- function(){
-        N_PC <- readline("What number of PC scores should be used as predictors? ")
-        return(N_PC)
-      }
-
-      N_PC <- fun()
-      response <- as.data.frame(PCA_result$scores[, 1:as.numeric(N_PC)])
-    }
-
-    number_PC <- ncol(response)
-    df_names <-  paste( "PC_", seq(1:number_PC), sep = "")
-    colnames(response) <- df_names
-
-  } else (PCA_result <- "No PCA result avalialbe !")
-
   # Subset of years
   if (!is.null(subset_years)){
     lower_subset <- subset_years[1]
@@ -742,8 +692,13 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
 
 
     if (fixed_width != max_window){
-      pb <- txtProgressBar(min = 0, max = (ncol(env_data_primary) - fixed_width - offset_end - offset_start + 1),
-                           style = 3)
+
+      if(interactive()){
+
+      pb <- txtProgressBar(min = 0, max = ceiling(((ncol(env_data_primary) - fixed_width - offset_end - offset_start + 1))/(skip_window_position)), style = 3)
+
+      }
+
     }
 
     b = 0
@@ -752,7 +707,7 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
       # response (dependent) variable. X is a moving average. Window width of
       # a moving window is fixed_width. Next, partial correlation is stored in
       # temporal matrix.
-    for (j in (0 + offset_start -1): (ncol(env_data_primary) - max((fixed_width + offset_end), offset_end))) {
+    for (j in (seq((0 + offset_start -1), (ncol(env_data_primary) - max((fixed_width + offset_end), offset_end)), by = skip_window_position))) {
 
         b = b + 1
 
@@ -821,9 +776,16 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
 
         if (!is.null(dc_method)){
 
-          x1 <- dplR::detrend(data.frame(x1), method = dc_method, nyrs = dc_nyrs, f = dc_f,
-                              pos.slope = dc_pos.slope, constrain.nls = dc_constrain.nls,
-                              span = dc_span, bass = dc_bass,  difference = dc_difference)
+
+          if (dc_method == "SLD"){
+
+            tmp_model <- lm(x1 ~ seq(1:length(x1)))
+            tmp_pred <- predict(tmp_model)
+            tmp_res <- x1 - tmp_pred
+
+            x1 <- data.frame(x1 = tmp_res/sd(tmp_res))
+
+          }
 
         } else {
 
@@ -834,9 +796,15 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
 
         if (!is.null(dc_method)){
 
-          x2 <- dplR::detrend(data.frame(x2), method = dc_method, nyrs = dc_nyrs, f = dc_f,
-                              pos.slope = dc_pos.slope, constrain.nls = dc_constrain.nls,
-                              span = dc_span, bass = dc_bass,  difference = dc_difference)
+          if (dc_method == "SLD"){
+
+            tmp_model <- lm(x2 ~ seq(1:length(x2)))
+            tmp_pred <- predict(tmp_model)
+            tmp_res <- x2 - tmp_pred
+
+            x2 <- data.frame(x2 = tmp_res/sd(tmp_res))
+
+          }
 
         } else {
 
@@ -937,10 +905,17 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
           print(paste0("boot should be TRUE or FALSE, instead it is ", boot))
 
           }
+          if(interactive()){
 
         if (fixed_width != max_window){setTxtProgressBar(pb, b)}
-      }
-    if (fixed_width != max_window){close(pb)}
+          }
+    }
+
+    if(interactive()){
+
+      if (fixed_width != max_window){close(pb)}
+
+    }
 
      # temporal_matrix is given rownames and colnames. Rownames represent a
      # window width used for calculations. Colnames represent the position of
@@ -991,18 +966,21 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
     temporal_matrix_upper <- temporal_matrix
 
     if (upper_limit != lower_limit){
+         if(interactive()){
 
-      pb <- txtProgressBar(min = 0, max = (upper_limit - lower_limit), style = 3)
-    }
+      pb <- txtProgressBar(min = 0, max = ceiling((upper_limit - lower_limit)/(skip_window_length*skip_window_position)), style = 3)
+
+      }
+
+          }
 
     b = 0
 
-
-  for (K in lower_limit:upper_limit) {
+  for (K in seq(lower_limit, upper_limit, by = skip_window_length)) {
 
     b = b + 1
 
-    for (j in (0 + offset_start -1): (ncol(env_data_primary) - max((K + offset_end), offset_end))) {
+    for (j in seq((0 + offset_start -1), (ncol(env_data_primary) - max((K + offset_end), offset_end)), by = skip_window_position)) {
 
       if (aggregate_function_env_data_primary == 'median'){
 
@@ -1110,9 +1088,16 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
 
       if (!is.null(dc_method)){
 
-        x1 <- dplR::detrend(data.frame(x1), method = dc_method, nyrs = dc_nyrs, f = dc_f,
-                            pos.slope = dc_pos.slope, constrain.nls = dc_constrain.nls,
-                            span = dc_span, bass = dc_bass,  difference = dc_difference)
+
+        if (dc_method == "SLD"){
+
+          tmp_model <- lm(x1 ~ seq(1:length(x1)))
+          tmp_pred <- predict(tmp_model)
+          tmp_res <- x1 - tmp_pred
+
+          x1 <- data.frame(x1 = tmp_res/sd(tmp_res))
+
+        }
 
       } else {
 
@@ -1123,9 +1108,16 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
 
       if (!is.null(dc_method)){
 
-        x2 <- dplR::detrend(data.frame(x2), method = dc_method, nyrs = dc_nyrs, f = dc_f,
-                            pos.slope = dc_pos.slope, constrain.nls = dc_constrain.nls,
-                            span = dc_span, bass = dc_bass,  difference = dc_difference)
+
+        if (dc_method == "SLD"){
+
+          tmp_model <- lm(x2 ~ seq(1:length(x2)))
+          tmp_pred <- predict(tmp_model)
+          tmp_res <- x2 - tmp_pred
+
+          x2 <- data.frame(x2 = tmp_res/sd(tmp_res))
+
+        }
 
       } else {
 
@@ -1228,12 +1220,21 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
 
       }
 
-      }
-    if (upper_limit != lower_limit){setTxtProgressBar(pb, b)}
-  }
+    }
 
-    if (upper_limit != lower_limit){close(pb)}
+        if(interactive()){
 
+             if (upper_limit != lower_limit){setTxtProgressBar(pb, b)}
+
+        }
+
+        }
+
+    if(interactive()){
+
+      if (upper_limit != lower_limit){close(pb)}
+
+    }
   # temporal_matrix is given rownames and colnames. Rownames represent a
   # window width used fot calculations. Colnames represent the position of
   # moving window in a original env_data_primary data frame.
@@ -1276,8 +1277,6 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
                        cross_validation = NA,
                        plot_heatmap = NA,
                        plot_extreme = NA,
-                       plot_specific = NA,
-                       PCA_output = PCA_result,
                        type = "daily",
                        reference_window = reference_window,
                        boot_lower = temporal_matrix_lower,
@@ -1482,7 +1481,7 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
 
 
   # Option 2, reference window = "end"
-    if (reference_window == 'end'){
+  if (reference_window == 'end'){
 
     if (aggregate_function_env_data_primary == 'median'){
       x1 <- data.frame(apply(data.frame(env_data_primary[, (as.numeric(plot_column) - as.numeric(row_index) + 1):
@@ -1726,13 +1725,22 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
 
   if (!is.null(dc_method)){
 
-    x1 <- dplR::detrend(x1, method = dc_method, nyrs = dc_nyrs, f = dc_f,
-                           pos.slope = dc_pos.slope, constrain.nls = dc_constrain.nls,
-                           span = dc_span, bass = dc_bass,  difference = dc_difference)
+    if (dc_method == "SLD"){
+
+      x1 <- x1[,1]
+      tmp_model <- lm(x1 ~ seq(1:length(x1)))
+      tmp_pred <- predict(tmp_model)
+      tmp_res <- x1 - tmp_pred
+      x1 <- data.frame(x1 = tmp_res/sd(tmp_res))
+
+      x2 <- x2[,1]
+      tmp_model <- lm(x2 ~ seq(1:length(x2)))
+      tmp_pred <- predict(tmp_model)
+      tmp_res <- x2 - tmp_pred
+      x2 <- data.frame(x2 = tmp_res/sd(tmp_res))
+
+    }
 
-    x2 <- dplR::detrend(x2, method = dc_method, nyrs = dc_nyrs, f = dc_f,
-                        pos.slope = dc_pos.slope, constrain.nls = dc_constrain.nls,
-                        span = dc_span, bass = dc_bass,  difference = dc_difference)
   }
 
   x1_full <- cbind(response, x1, x2)
@@ -1747,15 +1755,25 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
 
   if (!is.null(dc_method)){
 
-    x1_original <- dplR::detrend(x1_original, method = dc_method, nyrs = dc_nyrs, f = dc_f,
-                        pos.slope = dc_pos.slope, constrain.nls = dc_constrain.nls,
-                        span = dc_span, bass = dc_bass,  difference = dc_difference)
 
-    x2_original <- dplR::detrend(x2_original, method = dc_method, nyrs = dc_nyrs, f = dc_f,
-                                 pos.slope = dc_pos.slope, constrain.nls = dc_constrain.nls,
-                                 span = dc_span, bass = dc_bass,  difference = dc_difference)
+    if (dc_method == "SLD"){
+
+      x1_original <- x1_original[,1]
+      tmp_model <- lm(x1_original ~ seq(1:length(x1_original)))
+      tmp_pred <- predict(tmp_model)
+      tmp_res <- x1_original - tmp_pred
+      x1_original <- data.frame(x1_original = tmp_res/sd(tmp_res))
+
+      x2_original <- x2_original[,1]
+      tmp_model <- lm(x2_original ~ seq(1:length(x2_original)))
+      tmp_pred <- predict(tmp_model)
+      tmp_res <- x2_original - tmp_pred
+      x2_original <- data.frame(x2_original = tmp_res/sd(tmp_res))
+
     }
 
+  }
+
   # x1_full_original <- cbind(x1_original, x2_original)
   x1_full_original <- merge(x1_original, x2_original, by = 0, all = TRUE)
   colnames(x1_full_original)[1] <- "year"
@@ -1976,25 +1994,6 @@ for (m in 1:length(empty_list_datasets)){
     plot_heatmapA <- plot_heatmap(final_list, reference_window = reference_window, type = "daily")
     plot_extremeA <- plot_extreme(final_list, ylimits = ylimits, reference_window = reference_window, type = "daily")
 
-    width_sequence = seq(lower_limit, upper_limit)
-
-    if (is.null(plot_specific_window)){
-      (plot_specificA <- "plot_specific_window is not available. No plot_specific is made!")
-    } else if (fixed_width != 0){
-
-      if (fixed_width != plot_specific_window){
-        warning(paste0("plot_specific_window and fixed_width differ!",
-                       " fixed_wdith will be used to generate plot_specific!"))
-      }
-
-      plot_specific_window = fixed_width
-      plot_specificA <- plot_specific(final_list, window_width = plot_specific_window, ylimits = ylimits,
-                                      reference_window = reference_window)
-    } else if (plot_specific_window %in% width_sequence){
-      plot_specificA <- plot_specific(final_list, window_width = plot_specific_window, ylimits = ylimits,
-                                      reference_window = reference_window)
-    } else (plot_specificA <- "Selected plot_specific_window is not available. No plot_specific is made!")
-
 
       final_list <- list(calculations = temporal_matrix, method = "pcor",
                          metric = pcor_method, analysed_period = analysed_period,
@@ -2004,8 +2003,6 @@ for (m in 1:length(empty_list_datasets)){
                          cross_validation = NA,
                          plot_heatmap = plot_heatmapA,
                          plot_extreme = plot_extremeA,
-                         plot_specific = plot_specificA,
-                         PCA_output = PCA_result,
                          type = "daily",
                          reference_window = reference_window,
                          boot_lower = temporal_matrix_lower,
