@@ -4,8 +4,8 @@
 #' tree-ring chronology and monthly environmental (usually climate) data.
 #' All calculated (partial) correlation coefficients are stored in a matrix.
 #' The location of stored correlation in the matrix is indicating a window
-#' width (row names) and a location in a
-#' matrix of monthly sequences of environmental data (column names).
+#' width (row names) and a location in a matrix of monthly sequences of
+#' environmental data (column names).
 #'
 #' @param response a data frame with tree-ring proxy variable and (optional)
 #' years as row names. Row.names should be matched with those from env_data_primary
@@ -52,21 +52,6 @@
 #' @param row_names_subset if set to TRUE, row.names are used to subset
 #' env_data_primary, env_data_control and response data frames. Only years from
 #' all three data frames are kept.
-#' @param PCA_transformation if set to TRUE, all variables in the response
-#' data frame will be transformed using PCA transformation.
-#' @param log_preprocess if set to TRUE, variables will be transformed with
-#' logarithmic transformation before used in PCA
-#' @param components_selection character string specifying how to select the Principal
-#' Components used as predictors.
-#' There are three options: "automatic", "manual" and "plot_selection". If
-#' argument is set to automatic, all scores with eigenvalues above 1 will be
-#' selected. This threshold could be changed by changing the
-#' eigenvalues_threshold argument. If parameter is set to "manual", user should
-#' set the number of components with N_components argument. If components
-#' selection is set to "plot_selection", Scree plot will be shown and a user must
-#' manually enter the number of components to be used as predictors.
-#' @param eigenvalues_threshold threshold for automatic selection of Principal Components
-#' @param N_components number of Principal Components used as predictors
 #' @param aggregate_function_env_data_primary character string specifying how the
 #' monthly data from env_data_primary should be aggregated. The default is 'mean',
 #' the two other options are 'median' and 'sum'
@@ -85,10 +70,8 @@
 #' @param k integer, number of breaks (splits) for temporal stability
 #' @param subset_years a subset of years to be analyzed. Should be given in the form of
 #' subset_years = c(1980, 2005)
-#' @param plot_specific_window integer representing window width to be displayed
-#' for plot_specific
-#' @param ylimits limit of the y axes for plot_extreme and plot_specific. It should be
-#' given in the form of: ylimits = c(0,1)
+#' @param ylimits limit of the y axes for plot_extreme. It should be given in
+#' the form of: ylimits = c(0,1)
 #' @param seed optional seed argument for reproducible results
 #' @param tidy_env_data_primary if set to TRUE, env_data_primary should be inserted as a
 #' data frame with three columns: "Year", "Month", "Precipitation/Temperature/etc."
@@ -107,23 +90,8 @@
 #' previous growing season months. This argument overwrites the calculation
 #' limits defined by lower_limit and upper_limit arguments.
 #' @param dc_method a character string to determine the method to detrend climate
-#' (environmental) data.  Possible values are c("Spline", "ModNegExp", "Mean",
-#' "Friedman", "ModHugershoff"). Defaults to "none" (see dplR R package).
-#' @param dc_nyrs a number giving the rigidity of the smoothing spline, defaults
-#' to 0.67 of series length if nyrs is NULL (see dplR R package).
-#' @param dc_f a number between 0 and 1 giving the frequency response or wavelength
-#' cutoff. Defaults to 0.5 (see dplR R package).
-#' @param dc_pos.slope a logical flag. Will allow for a positive slope to be used
-#' in method "ModNegExp" and "ModHugershoff". If FALSE the line will be horizontal
-#' (see dplR R package).
-#' @param dc_constrain.nls a character string which controls the constraints of
-#' the "ModNegExp" model and the "ModHugershoff"  (see dplR R package).
-#' @param dc_span a numeric value controlling method "Friedman", or "cv" (default)
-#' for automatic choice by cross-validation (see dplR R package).
-#' @param dc_bass a numeric value controlling the smoothness of the fitted curve
-#' in method "Friedman" (see dplR R package).
-#' @param dc_difference	a logical flag. Compute residuals by subtraction if TRUE,
-#' otherwise use division (see dplR R package).
+#' data.  Possible values are "none" (default) and "SLD" which refers to Simple
+#' Linear Detrending
 #' @param pcor_na_use an optional character string giving a method for computing
 #' covariances in the presence of missing values for partial correlation
 #' coefficients. This must be (an abbreviation of) one of the strings "all.obs",
@@ -143,8 +111,6 @@
 #'  \item $cross_validation - not available for partial correlation method
 #'  \item $plot_heatmap - ggplot2 object: a heatmap of calculated metrics
 #'  \item $plot_extreme - ggplot2 object: line plot of a row with the highest value in a matrix of calculated metrics
-#'  \item $plot_specific - ggplot2 object: line plot of a row with a selected window width in a matrix of calculated metrics
-#'  \item $PCA_output - princomp object: the result output of the PCA analysis
 #'  \item $type - the character string describing type of analysis: monthly or monthly
 #'  \item $reference_window - character string, which reference window was used for calculations
 #'  \item $aggregated_climate_primary - matrix with all aggregated climate series of primary data
@@ -182,13 +148,12 @@
 #'    tidy_env_data_control = TRUE,
 #'    previous_year = TRUE)
 #'
-#' summary(example_basic)
-#' plot(example_basic, type = 1)
-#' plot(example_basic, type = 2)
-#' plot(example_basic, type = 3)
-#' example_basic$optimized_return
-#' example_basic$optimized_return_all
-#' example_basic$temporal_stability
+#' # summary(example_basic)
+#' # plot(example_basic, type = 1)
+#' # plot(example_basic, type = 2)
+#' # example_basic$optimized_return
+#' # example_basic$optimized_return_all
+#' # example_basic$temporal_stability
 #'
 #' # 2 Extended example
 #' example_extended <- monthly_response_seascorr(response = data_MVA,
@@ -203,11 +168,11 @@
 #'    tidy_env_data_primary = FALSE,
 #'    tidy_env_data_control = TRUE)
 #'
-#' summary(example_extended)
-#' plot(example_extended, type = 1)
-#' plot(example_extended, type = 2)
-#' example_extended$optimized_return
-#' example_extended$optimized_return_all
+#' # summary(example_extended)
+#' # plot(example_extended, type = 1)
+#' # plot(example_extended, type = 2)
+#' # example_extended$optimized_return
+#' # example_extended$optimized_return_all
 #'
 #' }
 
@@ -217,15 +182,11 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
                            upper_limit = 12, fixed_width = 0,
                            alpha = .05, row_names_subset = FALSE,
                            reference_window = "start",
-                           PCA_transformation = FALSE, log_preprocess = TRUE,
-                           components_selection = 'automatic',
-                           eigenvalues_threshold = 1,
-                           N_components = 2,
                            aggregate_function_env_data_primary = 'mean',
                            aggregate_function_env_data_control = 'mean',
                            temporal_stability_check = "sequential", k = 2,
                            k_running_window = 30,
-                           subset_years = NULL, plot_specific_window = NULL,
+                           subset_years = NULL,
                            ylimits = NULL, seed = NULL, tidy_env_data_primary = FALSE,
                            tidy_env_data_control = FALSE,  boot = FALSE, boot_n = 1000,
                            boot_ci_type = "norm", boot_conf_int = 0.95,
@@ -233,13 +194,6 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
                                                      previous_year == TRUE),
                                                    c(-1, 12), c(1, 12)),
                            dc_method = NULL,
-                           dc_nyrs = NULL,
-                           dc_f = 0.5,
-                           dc_pos.slope = FALSE,
-                           dc_constrain.nls = c("never", "when.fail", "always"),
-                           dc_span = "cv",
-                           dc_bass = 0,
-                           dc_difference = FALSE,
                            pcor_na_use = "pairwise.complete") {
 
   ##############################################################################
@@ -525,13 +479,13 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
   if (upper_limit > 24 | upper_limit < 1)
     stop("upper_limit out of bounds! It should be between 1 and 365")
 
+  # Make sure the selected method is appropriate
   # Make sure the selected method is appropriate
   if (!is.null(dc_method)){
 
-    if (!(dc_method %in% c("Spline", "ModNegExp", "Mean", "Friedman", "ModHugershoff"))){
+    if (!(dc_method %in% c("SLD"))){
 
-      stop(paste0('dc_method should be one of "Spline", "ModNegExp", "Mean", "Friedman", "ModHugershoff",
-         but instead it is:',dc_method))
+      stop(paste0('dc_method should be SLD but instead it is:',dc_method))
 
     }
   }
@@ -651,48 +605,6 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
                 "At least three characters needed!"))
   }
 
-  # If PCA_transformation = TRUE, PCA is performed
-  if (PCA_transformation == TRUE) {
-
-    # Logarithmic transformation before PCA
-    if (log_preprocess == TRUE) {
-
-      if (sum(response <= 0) > 1){
-        stop("your response data contains negative observations. Please set the argument log_preprocess to FALSE")
-      }
-
-      response <- data.frame(log(response))
-    }
-
-    PCA_result <- princomp(response, cor = TRUE)
-
-    if (components_selection == 'automatic'){
-      subset_vector <- PCA_result$sdev > eigenvalues_threshold
-      response <- as.data.frame(PCA_result$scores[, subset_vector])
-    }
-
-    if (components_selection == 'manual'){
-      response <- as.data.frame(PCA_result$scores[, 1:N_components])
-    }
-
-    if (components_selection == 'plot_selection'){
-      plot(PCA_result, type = 'l')
-
-      fun <- function(){
-        N_PC <- readline("What number of PC scores should be used as predictors? ")
-        return(N_PC)
-      }
-
-      N_PC <- fun()
-      response <- as.data.frame(PCA_result$scores[, 1:as.numeric(N_PC)])
-    }
-
-    number_PC <- ncol(response)
-    df_names <-  paste( "PC_", seq(1:number_PC), sep = "")
-    colnames(response) <- df_names
-
-  } else (PCA_result <- "No PCA result avalialbe !")
-
   # Subset of years
   if (!is.null(subset_years)){
     lower_subset <- subset_years[1]
@@ -771,9 +683,14 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
     temporal_matrix_upper <- temporal_matrix
 
     if (fixed_width != max_window){
-      pb <- txtProgressBar(min = 0, max = (ncol(env_data_primary) - fixed_width - offset_end - offset_start + 1),
+
+      if(interactive()){
+
+        pb <- txtProgressBar(min = 0, max = (ncol(env_data_primary) - fixed_width - offset_end - offset_start + 1),
                            style = 3)}
 
+        }
+
       b = 0
 
       # An iterating loop. In each iteration x is calculated and represents
@@ -825,9 +742,15 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
 
         if (!is.null(dc_method)){
 
-          x1 <- dplR::detrend(data.frame(x1), method = dc_method, nyrs = dc_nyrs, f = dc_f,
-                              pos.slope = dc_pos.slope, constrain.nls = dc_constrain.nls,
-                              span = dc_span, bass = dc_bass,  difference = dc_difference)
+          if (dc_method == "SLD"){
+
+          tmp_model <- lm(x1 ~ seq(1:length(x1)))
+          tmp_pred <- predict(tmp_model)
+          tmp_res <- x1 - tmp_pred
+
+          x1 <- data.frame(x1 = tmp_res/sd(tmp_res))
+
+          }
 
         } else {
 
@@ -837,9 +760,15 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
 
         if (!is.null(dc_method)){
 
-          x2 <- dplR::detrend(data.frame(x2), method = dc_method, nyrs = dc_nyrs, f = dc_f,
-                              pos.slope = dc_pos.slope, constrain.nls = dc_constrain.nls,
-                              span = dc_span, bass = dc_bass,  difference = dc_difference)
+          if (dc_method == "SLD"){
+
+            tmp_model <- lm(x2 ~ seq(1:length(x2)))
+            tmp_pred <- predict(tmp_model)
+            tmp_res <- x2 - tmp_pred
+
+            x2 <- data.frame(x2 = tmp_res/sd(tmp_res))
+
+          }
 
         } else {
 
@@ -939,10 +868,18 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
           print(paste0("boot should be TRUE or FALSE, instead it is ", boot))
         }
 
-        if (fixed_width != max_window){setTxtProgressBar(pb, b)}
+        if(interactive()){
+
+          if (fixed_width != max_window){setTxtProgressBar(pb, b)}
+
+        }
       }
 
-      if (fixed_width != max_window){close(pb)}
+      if(interactive()){
+
+        if (fixed_width != max_window){close(pb)}
+
+      }
 
      # temporal_matrix is given rownames and colnames. Rownames represent a
      # window width used for calculations. Colnames represent the position of
@@ -992,7 +929,12 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
     temporal_matrix_upper <- temporal_matrix
 
     if (upper_limit != lower_limit){
-      pb <- txtProgressBar(min = 0, max = (upper_limit - lower_limit), style = 3)
+
+      if(interactive()){
+
+        pb <- txtProgressBar(min = 0, max = (upper_limit - lower_limit), style = 3)
+
+      }
     }
 
   b = 0
@@ -1075,9 +1017,15 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
 
       if (!is.null(dc_method)){
 
-        x1 <- dplR::detrend(data.frame(x1), method = dc_method, nyrs = dc_nyrs, f = dc_f,
-                            pos.slope = dc_pos.slope, constrain.nls = dc_constrain.nls,
-                            span = dc_span, bass = dc_bass,  difference = dc_difference)
+        if (dc_method == "SLD"){
+
+          tmp_model <- lm(x1 ~ seq(1:length(x1)))
+          tmp_pred <- predict(tmp_model)
+          tmp_res <- x1 - tmp_pred
+
+          x1 <- data.frame(x1 = tmp_res/sd(tmp_res))
+
+        }
 
       } else {
 
@@ -1087,9 +1035,15 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
 
       if (!is.null(dc_method)){
 
-        x2 <- dplR::detrend(data.frame(x2), method = dc_method, nyrs = dc_nyrs, f = dc_f,
-                            pos.slope = dc_pos.slope, constrain.nls = dc_constrain.nls,
-                            span = dc_span, bass = dc_bass,  difference = dc_difference)
+        if (dc_method == "SLD"){
+
+          tmp_model <- lm(x2 ~ seq(1:length(x2)))
+          tmp_pred <- predict(tmp_model)
+          tmp_res <- x2 - tmp_pred
+
+          x2 <- data.frame(x2 = tmp_res/sd(tmp_res))
+
+        }
 
       } else {
 
@@ -1196,10 +1150,18 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
        }
     }
 
-    if (upper_limit != lower_limit){setTxtProgressBar(pb, b)}
+    if(interactive()){
+
+      if (upper_limit != lower_limit){setTxtProgressBar(pb, b)}
+
+    }
   }
 
-  if (upper_limit != lower_limit){close(pb)}
+  if(interactive()){
+
+      if (upper_limit != lower_limit){close(pb)}
+
+  }
 
   # temporal_matrix is given rownames and colnames. Rownames represent a
   # window width used fot calculations. Colnames represent the position of
@@ -1240,8 +1202,6 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
                        cross_validation = NA,
                        plot_heatmap = NA,
                        plot_extreme = NA,
-                       plot_specific = NA,
-                       PCA_output = PCA_result,
                        type = "monthly",
                        reference_window = reference_window,
                        boot_lower = temporal_matrix_lower,
@@ -1561,13 +1521,21 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
 
   if (!is.null(dc_method)){
 
-    x1 <- dplR::detrend(x1, method = dc_method, nyrs = dc_nyrs, f = dc_f,
-                        pos.slope = dc_pos.slope, constrain.nls = dc_constrain.nls,
-                        span = dc_span, bass = dc_bass,  difference = dc_difference)
+    if (dc_method == "SLD"){
 
-    x2 <- dplR::detrend(x2, method = dc_method, nyrs = dc_nyrs, f = dc_f,
-                        pos.slope = dc_pos.slope, constrain.nls = dc_constrain.nls,
-                        span = dc_span, bass = dc_bass,  difference = dc_difference)
+      x1 <- x1[,1]
+      tmp_model <- lm(x1 ~ seq(1:length(x1)))
+      tmp_pred <- predict(tmp_model)
+      tmp_res <- x1 - tmp_pred
+      x1 <- data.frame(x1 = tmp_res/sd(tmp_res))
+
+      x2 <- x2[,1]
+      tmp_model <- lm(x2 ~ seq(1:length(x2)))
+      tmp_pred <- predict(tmp_model)
+      tmp_res <- x2 - tmp_pred
+      x2 <- data.frame(x2 = tmp_res/sd(tmp_res))
+
+    }
   }
 
 
@@ -1583,13 +1551,21 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
 
   if (!is.null(dc_method)){
 
-    x1_original <- dplR::detrend(x1_original, method = dc_method, nyrs = dc_nyrs, f = dc_f,
-                                 pos.slope = dc_pos.slope, constrain.nls = dc_constrain.nls,
-                                 span = dc_span, bass = dc_bass,  difference = dc_difference)
+    if (dc_method == "SLD"){
 
-    x2_original <- dplR::detrend(x2_original, method = dc_method, nyrs = dc_nyrs, f = dc_f,
-                                 pos.slope = dc_pos.slope, constrain.nls = dc_constrain.nls,
-                                 span = dc_span, bass = dc_bass,  difference = dc_difference)
+      x1_original <- x1_original[,1]
+      tmp_model <- lm(x1_original ~ seq(1:length(x1_original)))
+      tmp_pred <- predict(tmp_model)
+      tmp_res <- x1_original - tmp_pred
+      x1_original <- data.frame(x1_original = tmp_res/sd(tmp_res))
+
+      x2_original <- x2_original[,1]
+      tmp_model <- lm(x2_original ~ seq(1:length(x2_original)))
+      tmp_pred <- predict(tmp_model)
+      tmp_res <- x2_original - tmp_pred
+      x2_original <- data.frame(x2_original = tmp_res/sd(tmp_res))
+
+    }
   }
 
   x1_full_original <- merge(x1_original, x2_original, by = 0, all = TRUE)
@@ -1801,25 +1777,6 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
     plot_heatmapA <- plot_heatmap(final_list, reference_window = reference_window, type = "monthly")
     plot_extremeA <- plot_extreme(final_list, ylimits = ylimits, reference_window = reference_window, type = "monthly")
 
-    width_sequence = seq(lower_limit, upper_limit)
-
-    if (is.null(plot_specific_window)){
-      (plot_specificA <- "plot_specific_window is not avaliable. No plot_specific is made!")
-    } else if (fixed_width != 0){
-
-      if (fixed_width != plot_specific_window){
-        warning(paste0("plot_specific_window and fixed_width differ!",
-                       " fixed_wdith will be used to generate plot_specific!"))
-      }
-
-      plot_specific_window = fixed_width
-      plot_specificA <- plot_specific(final_list, window_width = plot_specific_window, ylimits = ylimits,
-                                      reference_window = reference_window)
-    } else if (plot_specific_window %in% width_sequence){
-      plot_specificA <- plot_specific(final_list, window_width = plot_specific_window, ylimits = ylimits,
-                                      reference_window = reference_window)
-    } else (plot_specificA <- "Selected plot_specific_window is not avaliable. No plot_specific is made!")
-
       final_list <- list(calculations = temporal_matrix, method = "pcor",
                          metric = pcor_method, analysed_period = analysed_period,
                          optimized_return = x1_full,
@@ -1828,8 +1785,6 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
                          cross_validation = NA,
                          plot_heatmap = plot_heatmapA,
                          plot_extreme = plot_extremeA,
-                         plot_specific = plot_specificA,
-                         PCA_output = PCA_result,
                          type = "monthly",
                          reference_window = reference_window,
                          boot_lower = temporal_matrix_lower,
